==> guikachu-0.98.0.tar.gz: guikachu-0.98.0/src/string-res.h <==
//$Id: string-res.h,v 1.7 2001/11/03 19:18:30 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_STRING_RES_H
#define GUIKACHU_STRING_RES_H

namespace Guikachu
{
    namespace Resources
    {
	class String;
    }
}

#include "resource.h"

namespace Guikachu
{
    namespace GUI
    {
	class StringWindow;
    }
    
    namespace Resources
    {
	class String: public Resource
	{
	    GUI::StringWindow *gui;
	public:
	    String (const string& id);
	    virtual ~String ();

	    virtual Type get_type () const { return RESOURCE_STRING; };
	    virtual void show_ui ();

	    Property<string> text;

	private:
	    virtual bool load (StorageNode &node);
	    virtual void save (StorageNode &node) const;
	    virtual void save_rcp (ostream &ostr) const;
	};
    };
};

#endif /* !GUIKACHU_STRING_RES_H */

==> guikachu_1.0.1.orig.tar.gz: guikachu-1.0.1/src/string-res.h <==
//$Id: string-res.h,v 1.8 2001/11/06 12:54:53 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_STRING_RES_H
#define GUIKACHU_STRING_RES_H

namespace Guikachu
{
    namespace Resources
    {
	class String;
    }
}

#include "resource.h"

namespace Guikachu
{
    namespace GUI
    {
	class StringWindow;
    }
    
    namespace Resources
    {
	class String: public Resource
	{
	    GUI::StringWindow *gui;
	public:
	    String (const std::string& id);
	    virtual ~String ();

	    virtual Type get_type () const { return RESOURCE_STRING; };
	    virtual void show_ui ();

	    Property<std::string> text;

	private:
	    virtual bool load (StorageNode &node);
	    virtual void save (StorageNode &node) const;
	    virtual void save_rcp (std::ostream &ostr) const;
	};
    };
};

#endif /* !GUIKACHU_STRING_RES_H */
